/*
 * bufpointpainterarray.cc
 * 
 * Buffered point painter array. Point cache for performant point drawing 
 * in different colors. 
 * 
 * Copyright (c) 2002 by Wolfgang Wieser (wwieser@gmx.de) 
 * 
 * This file is part of QtXLib (Fast XLib drawing interface for Qt/X11). 
 * 
 * This file may be distributed and/or modified under the terms of the 
 * GNU General Public License version 2 as published by the Free Software 
 * Foundation. 
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 * 
 */

#include "bufpointpainterarray.h"

#include <stdlib.h>
#include <assert.h>

#include "qtxalloc.h"


namespace QTX
{

void BufferedPointPainterArray::Flush()
{
	for(uint i=0; i<asize; i++)
	{
		BufferedPointPainter *ppa=pa[i];
		if(ppa)
		{  ppa->Flush();  }
	}
}


int BufferedPointPainterArray::Flush(uint pidx)
{
	if(pidx>=asize)  return(1);
	BufferedPointPainter *ppa=pa[pidx];
	if(!ppa)  return(2);
	ppa->Flush();
	return(0);
}


void BufferedPointPainterArray::Setup(uint array_size)
{
	Flush();
	
	if(pa)
	{
		for(uint i=0; i<asize; i++)
		{  delete pa[i];  }
	}
	Free(pa);
	pa=NULL;
	
	asize=array_size;
	if(asize)
	{
		pa=(BufferedPointPainter**)Malloc(asize*sizeof(BufferedPointPainter*));
		for(uint i=0; i<asize; i++)
		{  pa[i]=NULL;  }
	}
}

int BufferedPointPainterArray::Setup(uint pidx,
	const QPaintDevice *pd,uint cache_size)
{
	if(pidx>=asize)  return(1);
	
	BufferedPointPainter *ppa=pa[pidx];
	if(ppa)  delete ppa;
	ppa=new BufferedPointPainter(pd,cache_size);
	pa[pidx]=ppa;
	
	return(0);
}

int BufferedPointPainterArray::Setup(uint pidx,
	const QPainter *qp,uint cache_size)
{
	if(pidx>=asize)  return(1);
	
	BufferedPointPainter *ppa=pa[pidx];
	if(ppa)  delete ppa;
	ppa=new BufferedPointPainter(qp->device(),cache_size);
	ppa->QCopyGC(*qp,/*brush=*/true);
	pa[pidx]=ppa;
	
	return(0);
}

}  // end of namespace QTX
